@@ -108,7 +108,8 @@ struct _ClutterGstPlayerIface
 
   gboolean (*get_idle) (ClutterGstPlayer *player);
 
-  void (* _iface_reserved15) (void);
+  gboolean (*get_in_seek) (ClutterGstPlayer *player);
+
   void (* _iface_reserved16) (void);
   void (* _iface_reserved17) (void);
   void (* _iface_reserved18) (void);
@@ -178,6 +179,8 @@ void                      clutter_gst_player_set_subtitle_track  (ClutterGstPlay
 
 gboolean                  clutter_gst_player_get_idle            (ClutterGstPlayer        *player);
 
+gboolean                  clutter_gst_player_get_in_seek         (ClutterGstPlayer        *player);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_GST_PLAYER_H__ */
