@@ -555,6 +555,12 @@ setup_pipeline (ClutterGstVideoTexture *video_texture)
     }
 
   video_sink = gst_element_factory_make ("autocluttersink", NULL);
+  if (!video_sink)
+    {
+      g_critical ("Unable to get autocluttersink");
+      return FALSE;
+    }
+
   g_signal_connect (video_sink,
 		    "element-added",
 		    G_CALLBACK (on_autocluttersink_element_added),
@@ -804,8 +810,8 @@ clutter_gst_video_texture_set_buffering_mode (ClutterGstVideoTexture *texture,
  *
  * Get the list of audio streams of the current media.
  *
- * Return value: (transfer none): a list of #GstTagList describing the
- * available audio streams
+ * Return value: (transfer none) (element-type Gst.TagList): a list of
+ * #GstTagList describing the available audio streams
  *
  * Since: 1.4
  */
@@ -857,8 +863,8 @@ clutter_gst_video_texture_set_audio_stream (ClutterGstVideoTexture *texture,
  *
  * Get the list of subtitles tracks of the current media.
  *
- * Return value: (transfer none): a list of #GstTagList describing the
- * available subtitles tracks
+ * Return value: (transfer none) (element-type Gst.TagList): a list
+ * of #GstTagList describing the available subtitles tracks
  *
  * Since: 1.4
  */
